@@ -1,8 +1,14 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE BangPatterns #-}
 {-# OPTIONS_HADDOCK hide #-}
 {-# LANGUAGE NoMonomorphismRestriction #-}
 {-# LANGUAGE NamedFieldPuns #-}
 {-# OPTIONS_GHC -funbox-strict-fields -O #-}
+
+#ifndef MIN_VERSION_base
+#defined MIN_VERSION_base(x,y,z) 1
+#endif
+
 module Data.Terminfo.Parse ( module Data.Terminfo.Parse
                            , Text.Parsec.ParseError
                            )
@@ -11,7 +17,6 @@ module Data.Terminfo.Parse ( module Data.Terminfo.Parse
 import Control.Monad ( liftM )
 import Control.DeepSeq
 
-import Data.Monoid
 import Data.Word
 import qualified Data.Vector.Unboxed as Vector
 
@@ -19,6 +24,10 @@ import Numeric (showHex)
 
 import Text.Parsec
 
+#if !(MIN_VERSION_base(4,8,0))
+import Data.Monoid
+#endif
+
 data CapExpression = CapExpression
     { capOps :: !CapOps
     , capBytes :: !(Vector.Vector Word8)
