@@ -7,8 +7,8 @@
 --  See also:
 --
 --  1. "Graphics.Vty.Output": This instantiates an abtract interface to the terminal interface based
---  on the TERM and COLORTERM environment variables. 
---  
+--  on the TERM and COLORTERM environment variables.
+--
 --  2. "Graphics.Vty.Output.Interface": Defines the generic interface all terminals need to implement.
 --
 --  3. "Graphics.Vty.Output.TerminfoBased": Defines a terminal instance that uses terminfo for all
@@ -17,7 +17,7 @@
 --
 --  4. "Graphics.Vty.Output.XTermColor": This module contains an interface suitable for xterm-like
 --  terminals. These are the terminals where TERM == xterm. This does use terminfo for as many
---  control codes as possible. 
+--  control codes as possible.
 module Graphics.Vty.Output ( module Graphics.Vty.Output
                            , Output(..) -- \todo hide constructors
                            , AssumedState(..)
@@ -27,7 +27,6 @@ module Graphics.Vty.Output ( module Graphics.Vty.Output
                            )
     where
 
-
 import Graphics.Vty.Prelude
 
 import Graphics.Vty.Config
@@ -40,10 +39,8 @@ import Blaze.ByteString.Builder (writeToByteString)
 
 import Control.Monad.Trans
 
-import Data.Monoid (mappend)
 import Data.List (isPrefixOf)
-
-import System.Posix.Env (getEnv)
+import Data.Monoid ((<>))
 
 -- | Returns a `Output` for the terminal specified in `Config`
 --
@@ -69,9 +66,9 @@ outputForConfig Config{ outputFd = Just fd, termName = Just termName, .. } = do
         -- Not an xterm-like terminal. try for generic terminfo.
         else TerminfoBased.reserveTerminal termName fd
     return t
-outputForConfig config = mappend config <$> standardIOConfig >>= outputForConfig
+outputForConfig config = (<> config) <$> standardIOConfig >>= outputForConfig
 
--- | Sets the cursor position to the given output column and row. 
+-- | Sets the cursor position to the given output column and row.
 --
 -- This is not necessarially the same as the character position with the same coordinates.
 -- Characters can be a variable number of columns in width.
@@ -91,11 +88,10 @@ hideCursor t = do
     bounds <- displayBounds t
     dc <- displayContext t bounds
     liftIO $ outputByteBuffer t $ writeToByteString $ writeHideCursor dc
-    
+
 -- | Shows the cursor
 showCursor :: MonadIO m => Output -> m ()
 showCursor t = do
     bounds <- displayBounds t
     dc <- displayContext t bounds
     liftIO $ outputByteBuffer t $ writeToByteString $ writeShowCursor dc
-
