@@ -3,6 +3,11 @@
 {-# LANGUAGE FlexibleInstances #-}
 {-# OPTIONS_GHC -D_XOPEN_SOURCE=500 -fno-warn-warnings-deprecations #-}
 {-# CFILES gwinsz.c #-}
+
+#ifndef MIN_VERSION_base
+#defined MIN_VERSION_base(x,y,z) 1
+#endif
+
 -- |  Terminfo based terminal handling.
 --
 -- The color handling assumes tektronix like. No HP support provided. If the terminal is not one I
@@ -28,10 +33,8 @@ import Blaze.ByteString.Builder (Write, writeToByteString)
 import Control.Monad.Trans
 
 import Data.Bits ((.&.))
-import Data.Foldable (foldMap)
 import Data.IORef
 import Data.Maybe (isJust, isNothing, fromJust)
-import Data.Monoid
 import Data.Word
 
 import Foreign.C.Types ( CInt(..), CLong(..) )
@@ -42,6 +45,11 @@ import qualified System.Console.Terminfo as Terminfo
 import System.Posix.IO (fdWriteBuf)
 import System.Posix.Types (Fd(..))
 
+#if !(MIN_VERSION_base(4,8,0))
+import Data.Foldable (foldMap)
+import Data.Monoid
+#endif
+
 data TerminfoCaps = TerminfoCaps 
     { smcup :: Maybe CapExpression
     , rmcup :: Maybe CapExpression
